@@ -301,8 +301,7 @@ class LoadMaster(HttpClient):
     def backup(self):
         # Dirty API, dirty hack.
         curl = ['curl', '-k', '{}/backup'.format(self.endpoint)]
-        file_name = "{}.backup".format(self.ip_address)
+        file_name = "backups/{}.backup".format(self.ip_address)
         with open(file_name, 'wb') as file:
             subprocess.call(curl, stdout=file)
         return file_name
-
